@@ -1001,7 +1001,7 @@ automatically exported.
 
 =head2 any
 
-  my $route = any '/:foo' => sub {...};
+  my $route = any '/:foo' => [foo => qr/\w+/] => sub {...};
   my $route = any [qw(GET POST)] => '/:foo' => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"any">, matching any of the
@@ -1016,14 +1016,14 @@ The L<Mojolicious::Lite> application.
 
 =head2 del
 
-  my $route = del '/:foo' => sub {...};
+  my $route = del '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"delete">, matching only
 C<DELETE> requests. See also the tutorial above for more argument variations.
 
 =head2 get
 
-  my $route = get '/:foo' => sub {...};
+  my $route = get '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"get">, matching only C<GET>
 requests. See also the tutorial above for more argument variations.
@@ -1048,7 +1048,7 @@ Share code with L<Mojolicious/"hook">.
 
 =head2 options
 
-  my $route = options '/:foo' => sub {...};
+  my $route = options '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"options">, matching only
 C<OPTIONS> requests. See also the tutorial above for more argument
@@ -1056,7 +1056,7 @@ variations.
 
 =head2 patch
 
-  my $route = patch '/:foo' => sub {...};
+  my $route = patch '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"patch">, matching only
 C<PATCH> requests. See also the tutorial above for more argument variations.
@@ -1069,14 +1069,14 @@ Load a plugin with L<Mojolicious/"plugin">.
 
 =head2 post
 
-  my $route = post '/:foo' => sub {...};
+  my $route = post '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"post">, matching only
 C<POST> requests. See also the tutorial above for more argument variations.
 
 =head2 put
 
-  my $route = put '/:foo' => sub {...};
+  my $route = put '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"put">, matching only C<PUT>
 requests. See also the tutorial above for more argument variations.
@@ -1092,7 +1092,7 @@ more argument variations.
 
 =head2 websocket
 
-  my $route = websocket '/:foo' => sub {...};
+  my $route = websocket '/:foo' => [foo => qr/\w+/] => sub {...};
 
 Generate route with L<Mojolicious::Routes::Route/"websocket">, matching only
 WebSocket handshakes. See also the tutorial above for more argument
